@@ -1,7 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ *
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -146,7 +149,7 @@ int geramail(const char *dirname, int debug, const char *outdir, int userip, cha
    fclose(fp_in);
    fclose(fp_top2);
 
-   sprintf(csort,"export LC_ALL=C;sort -n -T %s -r -k 2,2 -o %s %s", TempDir, top1, top2);
+   sprintf(csort,"sort -n -T %s -r -k 2,2 -o %s %s", TempDir, top1, top2);
    system(csort);
 
    unlink(top2);
@@ -248,22 +251,22 @@ int geramail(const char *dirname, int debug, const char *outdir, int userip, cha
       sprintf(wperc2,"%3.2f%%",perc2);
 
 #if defined(__FreeBSD__)
-      sprintf(preg,"%7d %20s %8s %15s %7s %10s %10qu %7s%%\n",posicao,user2,nacc,fixnum(tnbytes),wperc,buildtime(tnelap),tnelap,wperc2);
+      sprintf(preg,"%7d %20s %8s %15s %7s %10s %10qu %7s%%\n",posicao,user2,nacc,fixnum(tnbytes,1),wperc,buildtime(tnelap),tnelap,wperc2);
 #elif defined(__alpha) || __ALPHA
-      sprintf(preg,"%7d %20s %8s %15s %7s %10s %10ld %7s%%\n",posicao,user2,nacc,fixnum(tnbytes),wperc,buildtime(tnelap),tnelap,wperc2);
+      sprintf(preg,"%7d %20s %8s %15s %7s %10s %10ld %7s%%\n",posicao,user2,nacc,fixnum(tnbytes,1),wperc,buildtime(tnelap),tnelap,wperc2);
 #else
-      sprintf(preg,"%7d %20s %8s %15s %7s %10s %10lld %7s\n",posicao,user2,nacc,fixnum(tnbytes),wperc,buildtime(tnelap),tnelap,wperc2);
+      sprintf(preg,"%7d %20s %8s %15s %7s %10s %10lld %7s\n",posicao,user2,nacc,fixnum(tnbytes,1),wperc,buildtime(tnelap),tnelap,wperc2);
 #endif
 
       if(strstr(user,"TOTAL") != 0){
          sprintf(preg,"------- -------------------- -------- --------------- ------- ---------- ---------- -------\n");
          fputs(preg,fp_top3);
 #if defined(__FreeBSD__)
-         sprintf(preg,"%-7s %20s %8qu %15s %8s %9s %10qu\n",text[107]," ",ttnacc,fixnum(ttnbytes)," ",buildtime(ttnelap),ttnelap);
+         sprintf(preg,"%-7s %20s %8qu %15s %8s %9s %10qu\n",text[107]," ",ttnacc,fixnum(ttnbytes,1)," ",buildtime(ttnelap),ttnelap);
 #elif defined(__alpha) || __ALPHA
-         sprintf(preg,"%-7s %20s %8ld %15s %8s %9s %10ld\n",text[107]," ",ttnacc,fixnum(ttnbytes)," ",buildtime(ttnelap),ttnelap);
+         sprintf(preg,"%-7s %20s %8ld %15s %8s %9s %10ld\n",text[107]," ",ttnacc,fixnum(ttnbytes,1)," ",buildtime(ttnelap),ttnelap);
 #else
-         sprintf(preg,"%-7s %20s %8lld %15s %8s %9s %10lld\n",text[107]," ",ttnacc,fixnum(ttnbytes)," ",buildtime(ttnelap),ttnelap);
+         sprintf(preg,"%-7s %20s %8lld %15s %8s %9s %10lld\n",text[107]," ",ttnacc,fixnum(ttnbytes,1)," ",buildtime(ttnelap),ttnelap);
 #endif
       }
 
@@ -282,11 +285,11 @@ int geramail(const char *dirname, int debug, const char *outdir, int userip, cha
    sprintf(strip1,"%s",text[96]);
    strip_latin(strip1);
 #if defined(__FreeBSD__)
-   sprintf(preg,"%-7s %20s %8qu %15s %8s %9s %10qu\n",strip1," ",ttnacc/totuser,fixnum(tnbytes)," ",buildtime(ttnelap/totuser),ttnelap/totuser);
+   sprintf(preg,"%-7s %20s %8qu %15s %8s %9s %10qu\n",strip1," ",ttnacc/totuser,fixnum(tnbytes,1)," ",buildtime(ttnelap/totuser),ttnelap/totuser);
 #elif defined(__alpha) || __ALPHA
-   sprintf(preg,"%-7s %20s %8ld %15s %8s %9s %10ld\n",strip1," ",ttnacc/totuser,fixnum(tnbytes)," ",buildtime(ttnelap/totuser),ttnelap/totuser);
+   sprintf(preg,"%-7s %20s %8ld %15s %8s %9s %10ld\n",strip1," ",ttnacc/totuser,fixnum(tnbytes,1)," ",buildtime(ttnelap/totuser),ttnelap/totuser);
 #else
-   sprintf(preg,"%-7s %20s %8lld %15s %8s %9s %10lld\n",strip1," ",ttnacc/totuser,fixnum(tnbytes)," ",buildtime(ttnelap/totuser),ttnelap/totuser);
+   sprintf(preg,"%-7s %20s %8lld %15s %8s %9s %10lld\n",strip1," ",ttnacc/totuser,fixnum(tnbytes,1)," ",buildtime(ttnelap/totuser),ttnelap/totuser);
 #endif
    fputs(preg,fp_top3);
 
