@@ -1,7 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ *
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -449,6 +452,13 @@ int parmtest(char *buf)
          return;
       }
 
+      if(strstr(buf,"dansguardian_conf") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(DansGuardianConf,buf);
+         fixnone(DansGuardianConf);
+         return;
+      }
+
       if(strstr(buf,"squidguard_conf") != 0) {
          getword(wbuf,buf,' ');
          strcpy(SquidGuardConf,buf);
@@ -617,6 +627,12 @@ int parmtest(char *buf)
          return;
       }
 
+      if(strstr(buf,"dansguardian_report_limit") != 0) {
+         getword(wbuf,buf,' ');
+         DansGuardianReportLimit=atoi(buf);
+         return;
+      }
+
       if(strstr(buf,"squidguard_report_limit") != 0) {
          getword(wbuf,buf,' ');
          SquidGuardReportLimit=atoi(buf);
@@ -719,6 +735,13 @@ int parmtest(char *buf)
          fixnone(Ulimit);
          return;
       }
+
+      if(strstr(buf,"ntlm_user_format") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(NtlmUserFormat,buf);
+         fixnone(NtlmUserFormat);
+         return;
+      }
     
       return;
 }
