@@ -1,7 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ *
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -33,9 +36,41 @@ int gray;
 int silver;
 int black;
 int x1;
-char *font1 = SYSCONFDIR"/fonts/Verdana.TTF";
+char *font1 = SYSCONFDIR"/fonts/FreeSans.ttf";
 char s[15];
 
+#ifdef HAVE_ICONV_H
+#include <iconv.h>
+#define SARGgdImageStringFT I18NgdImageStringFT
+
+BGD_DECLARE(char *) I18NgdImageStringFT (gdImage * im, int *brect, int fg, char *fontlist,
+                         double ptsize, double angle, int x, int y,
+                                                 char *string)
+{
+ iconv_t localtoutf;
+ char *sstring, *str, *sstr, *retval;
+ size_t slen, sslen;
+
+ slen = strlen(string) + 1; // We must include string termination character
+ sslen = slen * 2;          // We assume that UTF8 maximum 2 times large than local
+ sstring = (char *)malloc(sslen);
+
+ str = (char *) string;
+ sstr = (char *) sstring;
+
+ localtoutf = iconv_open ("UTF-8", CharSet);
+ iconv (localtoutf, &str, &slen, &sstr, &sslen);
+ iconv_close (localtoutf);
+
+ retval = gdImageStringFTEx (im, brect, fg, fontlist, ptsize, angle, x, y, sstring, gdFTEX_Unicode);
+ free(sstring);
+
+ return retval;
+}
+#else
+#define SARGgdImageStringFT gdImageStringFT
+#endif
+
 void *bar(long long int *n)
 {     
 #ifdef HAVE_GD
@@ -108,6 +143,11 @@ void *bar(long long int *n)
 	"3900000000","4000000000","4100000000","4200000000","4300000000","4400000000",
 	"4500000000","4600000000","4700000000","4800000000","4900000000","5000000000"};
 
+   if(access(font1, R_OK) != 0) {
+     fprintf(stderr, "SARG: (grepday) Fontname: %s not found.\n",font1);
+     exit(1);
+   }
+
    if(strcmp(GraphDaysBytesBarColor,"orange") == 0) {
       color1 = gdImageColorAllocate(im, 255, 233, 142);
       color2 = gdImageColorAllocate(im, 220, 163, 72);
@@ -171,31 +211,9 @@ void *bar(long long int *n)
    gdImageFilledRectangle(im, x1-2, val-20, x1+18, val-10, goldenrod);
    gdImageRectangle(im, x1-2, val-20, x1+18, val-10, goldenrod2);
 
-   if(num < 1000) {
-      f=num;
-      sprintf(v,"%3.0f",f);
-   }
-   if(num > 999 && num <= 999999) {
-      f=num / 1000;
-      if((num % 1000) >= 500) f++;
-      sprintf(v,"%3.0fK",f);
-   }
-   if(num >999999 && num <= 999999999) {
-      f=num / 1000000;
-      if((num % 1000000) >= 500) f++;
-      sprintf(v,"%3.0fM",f);
-   }
-   if(num > 999999999 && num <= 999999999999) {
-      f=num / 1000000000;
-      if((num % 1000000000) >= 500) f++;
-      sprintf(v,"%3.0fG",f);
-   }
-   if(num > 999999999999) {
-      f=num / 1000000000000;
-      if((num % 1000000000000) >= 500) f++;
-      sprintf(v,"%3.0fT",f);
-   }
-   gdImageStringFT(im,&brect[0],black,font1,5,0.0,x1-1,val-12,v);
+   snprintf(v,6,"%s",fixnum(num,0));
+
+   SARGgdImageStringFT(im,&brect[0],black,font1,6,0.0,x1-1,val-12,v);
    
    points[0].x = x1+17;
    points[0].y = val-5;
@@ -292,7 +310,7 @@ void greport_day(char *user, int *iprel, int *ipuser)
    y=65;
    for(x=1; x<=31; x++) {
       sprintf(s,"%02d",x);
-      gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,y,437,s);
+      SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,y,437,s);
       y=y+20;
    }
 
@@ -303,59 +321,62 @@ void greport_day(char *user, int *iprel, int *ipuser)
    if(strcmp(DateFormat,"e") == 0)
       strftime(ftime, 127, "%d/%b/%Y-%H:%M", local);
 
-   gdImageStringFT(im,&brect[0],darkblue,font1,6,0.0,620,470,ftime);
-   gdImageStringFT(im,&brect[0],darkblue,font1,9,0.0,257,15,"SARG, ");
-   gdImageStringFT(im,&brect[0],darkblue,font1,9,0.0,300,15,Title);
+   SARGgdImageStringFT(im,&brect[0],darkblue,font1,7,0.0,620,470,ftime);
+   if(strcmp(ShowSargInfo,"yes") == 0) SARGgdImageStringFT(im,&brect[0],darkblue,font1,10,0.0,257,15,"SARG, ");
+   SARGgdImageStringFT(im,&brect[0],darkblue,font1,10,0.0,300,15,Title);
    sprintf(warea,"%s: %s",text[89],periodo);
-   gdImageStringFT(im,&brect[0],darkblue,font1,7,0.0,300,27,warea);
+   SARGgdImageStringFT(im,&brect[0],darkblue,font1,9,0.0,300,27,warea);
    sprintf(warea,"%s: %s",text[90],name);
-   gdImageStringFT(im,&brect[0],darkblue,font1,7,0.0,300,38,warea);
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,418,"  50K");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,408,"250K");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,398,"500K");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,388,"   1M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,378,"   2M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,368,"   3M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,358,"   4M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,348,"   5M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,338,"   6M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,328,"   7M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,318,"   8M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,308,"   9M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,298," 10M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,288," 15M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,278," 20M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,268," 30M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,258," 40M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,248," 50M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,238," 60M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,228," 70M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,218," 80M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,208," 90M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,198,"100M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,188,"200M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,178,"300M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,168,"400M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,158,"500M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,148,"600M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,138,"700M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,128,"800M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,118,"900M");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,108,"   1G");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23, 98,"   2G");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23, 88,"   3G");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23, 78,"   4G");
-   gdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23, 68,"   5G");
-   gdImageStringFT(im,&brect[0],black,font1,10,3.14/2,20,248,text[93]);
-   gdImageStringFT(im,&brect[0],black,font1,10,0.0,330,460,text[127]);
+   SARGgdImageStringFT(im,&brect[0],darkblue,font1,9,0.0,300,38,warea);
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,418,"  50K");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,408,"250K");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,398,"500K");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,388,"   1M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,378,"   2M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,368,"   3M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,358,"   4M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,348,"   5M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,338,"   6M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,328,"   7M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,318,"   8M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,308,"   9M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,298," 10M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,288," 15M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,278," 20M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,268," 30M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,258," 40M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,248," 50M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,238," 60M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,228," 70M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,218," 80M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,208," 90M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,198,"100M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,188,"200M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,178,"300M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,168,"400M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,158,"500M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,148,"600M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,138,"700M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,128,"800M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,118,"900M");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23,108,"   1G");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23, 98,"   2G");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23, 88,"   3G");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23, 78,"   4G");
+   SARGgdImageStringFT(im,&brect[0],dimgray,font1,7,0.0,23, 68,"   5G");
+   SARGgdImageStringFT(im,&brect[0],black,font1,10,3.14/2,20,248,text[93]);
+   SARGgdImageStringFT(im,&brect[0],black,font1,10,0.0,330,460,text[127]);
  
    sprintf(graph,"%s/%s/graph_day.png",dirname,user);
    sprintf(wdirname,"%s/%s.day",tmp,user);
    sprintf(tmp5,"%s/%s.graph",tmp,user);
 
-   sprintf(csort,"export LC_ALL=C;sort -t'/' -k 2,2 -o %s %s",tmp5,wdirname);
+   if(access(wdirname, R_OK) != 0)
+      return;
+
+   sprintf(csort,"sort -t'/' -k 2,2 -o %s %s",tmp5,wdirname);
    if(strcmp(DateFormat,"e") == 0)
-      sprintf(csort,"export LC_ALL=C;sort -t'/' -k 1,1 -o %s %s",tmp5,wdirname);
+      sprintf(csort,"sort -t'/' -k 1,1 -o %s %s",tmp5,wdirname);
 
    system(csort);
 
