@@ -1,7 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ *
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -319,9 +322,9 @@ void htmlrel()
          } else ouperc=0;
    
          twork=my_atoll(nacc);
-         sprintf(wwork1,"%s",fixnum(twork));
-         sprintf(wwork2,"%s",fixnum(nnbytes));
-         sprintf(wwork3,"%s",fixnum(nnelap));
+         sprintf(wwork1,"%s",fixnum(twork,1));
+         sprintf(wwork2,"%s",fixnum(nnbytes,1));
+         sprintf(wwork3,"%s",fixnum(nnelap,1));
 
          if(strcmp(LongUrl,"yes") != 0) {
             getword(warea,url,'/');
@@ -349,23 +352,11 @@ void htmlrel()
                for(s=ltext110; *s; ++s)
                   *s=tolower(*s);
             }
-            z1=0;
-            z2=0;
-            strcpy(siteind,url);
+            strcpy(siteind,urly);
             str=siteind;
-            for(z1=0; z1<=strlen(str); z1++) {
-               if(str[z1]=='-')
+            for(z1=0; z1<strlen(str); z1++) {
+	       if(str[z1]=='?' || str[z1]=='-' || str[z1]=='.' || str[z1]==':' || str[z1]=='/' || str[z1]=='\\')
                   str[z1]='_';
-               if(str[z1]=='.')
-                  str[z1]='_';
-               if(str[z1]==':')
-                  str[z1]='_';
-               if(str[z1]=='/')
-                  str[z1]='_';
-               if(str[z1]=='\\')
-                  str[z1]='_';
-               siteind[z2]=str[z1];
-               z2++;
             }
             sprintf(href2,"<a href=\"tt%s-%s.html\"><img src=\"../../images/datetime.png\" border=\"0\" title=\"%s %s\"></a>",usuario,siteind,ltext110,text[55]);
          } else {
@@ -446,7 +437,7 @@ void htmlrel()
             fclose(fp_ip);
             fclose(fp_ip2);
 
-            sprintf(csort,"export LC_ALL=C;sort -n -T %s -k 1,1 -k 5,5 -o %s %s",TempDir,tmp3,tmp2);
+            sprintf(csort,"sort -n -T %s -k 1,1 -k 5,5 -o %s %s",TempDir,tmp3,tmp2);
             system(csort);
    
             if ((fp_ip = fopen(tmp3, "r")) == 0) {
@@ -466,7 +457,7 @@ void htmlrel()
             while(!feof(fp_ip)) {
                if(strcmp(user_ip,olduserip) != 0) {
                   my_lltoa(unelap,val2,0);
-                  sprintf(wwork1,"%s",fixnum(unbytes));
+                  sprintf(wwork1,"%s",fixnum(unbytes,1));
                   sprintf(html,"<tr><td></td><td class=\"data\">%s</td><td></td><td class=\"data\">%s</td><td></td><td></td><td></td><td class=\"data\">%s</td><td class=\"data\">%s</td></tr>\n",olduserip,wwork1,buildtime(unelap),val2);
                   fputs(html,fp_ou);
   
@@ -494,7 +485,7 @@ void htmlrel()
             unlink(tmp3);
 
             my_lltoa(unelap,val3,0);
-            sprintf(wwork1,"%s",fixnum(unbytes));
+            sprintf(wwork1,"%s",fixnum(unbytes,1));
             sprintf(html,"<tr><td></td><td class=\"data\">%s</td><td></td><td class=\"data\">%s</td><td></td><td></td><td></td><td class=\"data\">%s</td><td class=\"data\">%s</font></td></tr>\n",olduserip,wwork1,buildtime(unelap),val3);
             fputs(html,fp_ou);
          }
@@ -538,9 +529,9 @@ void htmlrel()
          inperc=inperc / tnbytes;
       } else inperc=0;
    
-      sprintf(wwork1,"%s",fixnum(tnacc));
-      sprintf(wwork2,"%s",fixnum(tnbytes));
-      sprintf(wwork3,"%s",fixnum(tnelap));
+      sprintf(wwork1,"%s",fixnum(tnacc,1));
+      sprintf(wwork2,"%s",fixnum(tnbytes,1));
+      sprintf(wwork3,"%s",fixnum(tnelap,1));
 
       sprintf(val2,"%s%s",href2,ltext110);
       sprintf(val3,"%3.2f%%",perc);
@@ -662,9 +653,9 @@ void htmlrel()
       twork2=my_atoll(totuser);
       twork=ttnacc/twork2;
   
-      sprintf(wwork1,"%s",fixnum(twork));
-      sprintf(wwork2,"%s",fixnum(totbytes2));
-      sprintf(wwork3,"%s",fixnum(totelap2));
+      sprintf(wwork1,"%s",fixnum(twork,1));
+      sprintf(wwork2,"%s",fixnum(totbytes2,1));
+      sprintf(wwork3,"%s",fixnum(totelap2,1));
 
       sprintf(val6,"%s",buildtime(totelap2));
       sprintf(val7,"%3.2f%%",perc2); 
