@@ -191,6 +191,7 @@ char DataFileFields[MAXLEN];
 char SiteUserTimeDateType[10];
 char ShowReadStatistics[5];
 char IndexSortOrder[5];
+char DansGuardianConf[MAXLEN];
 char SquidGuardConf[MAXLEN];
 char SquidGuarddbHome[255];
 char SquidGuardLogFormat[MAXLEN];
@@ -205,6 +206,7 @@ char wwwDocumentRoot[MAXLEN];
 char ExternalCSSFile[MAXLEN];
 char BlockIt[255];
 char BlockImage[512];
+char NtlmUserFormat[30];
 char hbc1[30];
 char hbc2[255];
 char hbc3[30];
@@ -263,6 +265,7 @@ int  smartfilter;
 int  denied_count;
 int  download_count;
 int  authfail_count;
+int  dansguardian_count;
 int  squidguard_count;
 int  limit_flag;
 int  color1;
@@ -286,6 +289,7 @@ int  debugm;
 int  AuthfailReportLimit;
 int  DeniedReportLimit;
 int  SiteUsersReportLimit;
+int  DansGuardianReportLimit;
 int  SquidGuardReportLimit;
 int  UserReportLimit;
 int  download_flag;
