@@ -1,7 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ *
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -78,6 +81,7 @@ void geraindex()
       bzero(newname, 512);
       strncat(newname,direntp->d_name,4);
       strncpy(month,direntp->d_name+4,3);
+      month[3]='\0';
       conv_month(month);
       strcat(newname,month);
       strncat(newname,direntp->d_name+7,2);
@@ -109,9 +113,11 @@ void geraindex()
    (void)closedir( dirp );
 
    if(strcmp(IndexSortOrder,"A") == 0)
-      sprintf(html,"export LC_ALL=C;sort -t';' -k 7,7 %s -o %s", wdir_tmp, wdir_tmp2);
+//      sprintf(html,"sort -t';' -k 7,7 %s -o %s", wdir_tmp, wdir_tmp2);
+      sprintf(html,"sort -t';' +6.5n +6.2M +6.0n '%s' -o '%s'", wdir_tmp, wdir_tmp2);
    else
-      sprintf(html,"export LC_ALL=C;sort -t';' -r -k 7,7 %s -o %s", wdir_tmp, wdir_tmp2);
+//      sprintf(html,"sort -t';' -r -k 7,7 %s -o %s", wdir_tmp, wdir_tmp2);
+      sprintf(html,"sort -t';' +6.5nr +6.2Mr +6.0nr '%s' -o '%s'", wdir_tmp, wdir_tmp2);
 
    system(html);
 
