@@ -1,7 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ *
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -64,7 +67,7 @@ void mklastlog()
    (void)closedir( dirp );
    fclose(fp_ou);
    
-   sprintf(buf,"export LC_ALL=C;sort -n -k 1,1 -o %slastlog %s",outdir,temp);
+   sprintf(buf,"sort -n -k 1,1 -o %slastlog %s",outdir,temp);
    system(buf);
 
    unlink(temp);
