@@ -1,5 +1,5 @@
 /*
- * AUTHOR: Pedro Lineu Orso		              rso@brturbo.com.br
+ * AUTHOR: Pedro Lineu Orso		             orso@brturbo.com.br
  *                                                            1998, 2005
  * SARG Squid Analysis Report Generator	           http://sarg-squid.org
  * 
@@ -87,7 +87,8 @@ int main(argc,argv)
    char arq[255];
    char arq_log[255];
    char warq[255][255];
-   char hm[6];
+   char hm[15], hmf[15], hmr[15], whm[15];
+   int  chm=0;
    char uagent[MAXLEN];
    char hexclude[MAXLEN];
    char csort[MAXLEN]; 
@@ -205,9 +206,10 @@ int main(argc,argv)
    strcpy(AuthName,"SARG, Restricted Access");
    strcpy(AuthType,"basic");
    strcpy(Require,"require user admin %u");
-   strcpy(DownloadSuffix,"zip,arj,bzip,gz,ace,doc,iso,adt,bin,cab,dot,drv$,lha,lzh,mdb,mso,ppt,rtf,src,shs,sys,exe,dll,mp3,avi,mpg,mpeg");
+   strcpy(DownloadSuffix,"7z,ace,arj,avi,bat,bin,bz2,bzip,cab,com,cpio,dll,doc,dot,exe,gz,iso,lha,lzh,mdb,mov,mp3,mpeg,mpg,mso,nrg,ogg,ppt,rar,rtf,shs,src,sys,tar,tgz,vcd,vob,wma,wmv,zip");
    strcpy(Graphs,"yes");
    strcpy(Ulimit,"20000");
+   strcpy(NtlmUserFormat,"domainname+username");
 
    dia[0]='\0';
    mes[0]='\0';
@@ -225,6 +227,7 @@ int main(argc,argv)
    hexclude[0]='\0';
    addr[0]='\0';
    hm[0]='\0';
+   hmf[0]='\0';
    site[0]='\0';
    outdir[0]='\0';
    elap[0]='\0';
@@ -233,14 +236,17 @@ int main(argc,argv)
    UserInvalidChar[0]='\0';
    DataFile[0]='\0';
    SquidGuardConf[0]='\0';
+   DansGuardianConf[0]='\0';
 
    excode=0;
    denied_count=0;
    download_count=0;
    authfail_count=0;
+   dansguardian_count=0;
    squidguard_count=0;
    DeniedReportLimit=10;
    AuthfailReportLimit=10;
+   DansGuardianReportLimit=10;
    SquidGuardReportLimit=10;
    UserReportLimit=0;
    debug=0;
@@ -319,7 +325,29 @@ int main(argc,argv)
             strcpy(site,optarg);
             break;
          case 't':
-            strcpy(hm,optarg);
+            if(strstr(optarg,"-") == 0) {
+              strcpy(hm,optarg);
+              strcpy(hmf,optarg);
+            } else {
+               getword(hm,optarg,'-');
+               strcpy(hmf,optarg);
+            }
+            if(strlen(hm) > 5) {
+	       printf("SARG: time period must be MM or MM:SS. Exit.\n");
+	       exit(1);
+            }
+            bzero(whm,15);
+            if(strstr(hm,":") != 0) {
+               getword(warea,hm,':');
+               sprintf(whm,"%s%s",warea,hm);
+               strcpy(hm,whm);
+            }
+            bzero(whm,15);
+            if(strstr(hmf,":") != 0) {
+               getword(warea,hmf,':');
+               sprintf(whm,"%s%s",warea,hmf);
+               strcpy(hmf,whm);
+            }
             break;
          case 'u':
             strcpy(us,optarg);
@@ -638,21 +666,20 @@ int main(argc,argv)
       sprintf(msg,"sarg %s: %s",text[73],VERSION);
       debuga(msg);
    }
-
-#if defined(__FreeBSD__)
-   getrlimit (RLIMIT_OFILE, &rl);
-#else
+#if defined(RLIMIT_NOFILE)
    getrlimit (RLIMIT_NOFILE, &rl);
+#else #if defined(RLIMIT_OFILE)
+   getrlimit (RLIMIT_OFILE, &rl);
 #endif
    l1 = rl.rlim_cur;
    l2 = rl.rlim_max;
 
    rl.rlim_cur = atol(Ulimit);
    rl.rlim_max = atol(Ulimit);
-#if defined(__FreeBSD__)
-   if(setrlimit (RLIMIT_OFILE, &rl) == -1) {
-#else
+#if defined(RLIMIT_NOFILE)
    if(setrlimit (RLIMIT_NOFILE, &rl) == -1) {
+#else #if defined(RLIMIT_OFILE)
+   if(setrlimit (RLIMIT_OFILE, &rl) == -1) {
 #endif
       sprintf(msg,"setrlimit error - %s\n",strerror(errno));
       debuga(msg);
@@ -663,8 +690,6 @@ int main(argc,argv)
       debuga(msg);
    }
 
-//   system("export LC_ALL=C");
-
    if(UserTabFile[0] != '\0') {
       if(debug) {
          sprintf(msg,"%s: %s",text[86],UserTabFile);
@@ -727,7 +752,7 @@ int main(argc,argv)
    }
    fgets(bufz,sizeof(bufz),fp_in);
    if(!isalog) {
-      if(strncmp(bufz,"#Software: Microsoft(R)",23) == 0)
+      if(strncmp(bufz,"#Software: Mic",14) == 0)
          isalog++;
    }
    if(strncmp(bufz,"*** SARG Log ***",16) == 0) {
@@ -845,11 +870,13 @@ int main(argc,argv)
 	         getword(data,bufz,']');
 	         getword(fun,bufz,'"');
 	         getword(fun,bufz,' ');
-	         getword(url,bufz,'"');
+	         getword(url,bufz,' ');
                  getword(code2,bufz,' ');
                  getword(code2,bufz,' ');
                  getword(tam,bufz,' ');
-                 strcpy(code,bufz);
+                 if((str=(char *) strstr(bufz, " ")) != (char *) NULL )
+                    getword(code,bufz,' ');
+                 else strcpy(code,bufz);
 
                  if ((str = strchr(code, ':')) != NULL)
                     *str = '/'; 
@@ -952,25 +979,19 @@ int main(argc,argv)
            sprintf(user,"%s.%s",w,wuser);
         }
 
-	z1=0;
-	z2=0;
 	str=user;
-	for(z1=0; z1<=strlen(str); z1++) {
+	for(z1=0; z1<strlen(str); z1++) {
 	   if(isalnum(str[z1]) || ispunct(str[z1])) {
-	      if(str[z1]=='/')
-	         str[z1]='_';
-	      if(str[z1]=='\\')
-	         str[z1]='_';
-	      if(str[z1]==';')
-	         str[z1]='_';
-	      if(str[z1]=='\'')
-	         str[z1]='_';
-	      user[z2]=str[z1];
-	      z2++;
+	   if(str[z1]=='?' || str[z1]=='.' || str[z1]==':' || str[z1]=='/' || str[z1]=='\\')
+	      str[z1]='_';
 	   }
 	}
 
         strlow(user);
+        if(strncmp(NtlmUserFormat,"user",4) == 0) {
+           if(strstr(user,"_") != 0)
+              getword(warea,user,'_');  
+        }
 
         if(strstr(ReportType,"denied") != 0)
            strcpy(urly,url);
@@ -1069,8 +1090,18 @@ int main(argc,argv)
  	   }
         }
         if(l){
-           if(strlen(hm)>0){
-  	      if(strncmp(hm,hora,strlen(hm))==0)
+           if(strlen(hm)>0) {
+              strcpy(whm,hora);
+              bzero(hmr,15);
+              chm++;
+              while(chm) {
+                 getword(warea,whm,':');
+                 strncat(hmr,warea,2);
+                 chm--;
+              }
+              strncat(hmr,whm,2);
+
+  	      if(atoi(hmr) >= atoi(hm) && atoi(hmr) <= atoi(hmf))
 	         l=1;else l=0;
  	   }
         }
