@@ -1,7 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ *
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -57,13 +60,16 @@ void report_day(char *user, int *iprel, int *ipuser)
    sprintf(arqout,"%s/%s/d%s.html",dirname,user,user);
    sprintf(wdirname,"%s/%s.day",tmp,user);
 
+   if(access(wdirname, R_OK) != 0)
+      return;
+
    if((fp_in=fopen(wdirname,"r"))==NULL) {
-     fprintf(stderr, "SARG: (totday) %s: %s\n",text[8],wdirname);
+     fprintf(stderr, "SARG: (repday) %s: %s\n",text[8],wdirname);
      exit(1);
    }
 
    if((fp_ou=fopen(arqout,"w"))==NULL) {
-     fprintf(stderr, "SARG: (totday) %s: %s\n",text[8],arqout);
+     fprintf(stderr, "SARG: (repday) %s: %s\n",text[8],arqout);
      exit(1);
    }
 
