@@ -1,7 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ *
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -107,6 +110,8 @@ void gerarel()
          getword(accurl,buf,' ');
          getword(accbytes,buf,' ');
          getword(acccode,buf,' ');
+         if(strncmp(acccode,"TCP_DENIED/407",14) == 0)
+            continue;
          getword(accelap,buf,' ');
          getword(accsmart,buf,' ');
          getword(accsmart,buf,'"');
@@ -184,22 +189,10 @@ void gerarel()
          if(!ttopen) {
             ind2++;
 	    strcpy(siteind,accurl);
-            z1=0;
-	    z2=0;
 	    str=siteind;
-	    for(z1=0; z1<=strlen(str); z1++) {
-	       if(str[z1]=='-')
-                  str[z1]='_';
-	       if(str[z1]=='.')
-                  str[z1]='_';
-	       if(str[z1]==':')
-                  str[z1]='_';
-	       if(str[z1]=='/')
-                  str[z1]='_';
-	       if(str[z1]=='?')
-                  str[z1]='_';
-               siteind[z2]=str[z1];
-               z2++;
+	    for(z1=0; z1<strlen(str); z1++) {
+	    if(str[z1]=='?' || str[z1]=='-' || str[z1]=='.' || str[z1]==':' || str[z1]=='/' || str[z1]=='\\')
+	                     str[z1]='_';
             }
 	    sprintf(arqtt,"%s/%s",dirname,accuser);
 	    if(access(arqtt, R_OK) != 0)
@@ -343,6 +336,11 @@ void gerarel()
    if(strlen(email) == 0) {
       download_report();
 
+      if(strlen(DansGuardianConf) > 0) {
+         strcpy(wdirname,dirname);
+         dansguardian_log();
+      }
+
       if(strlen(SquidGuardConf) > 0) {
          strcpy(wdirname,dirname);
          squidguard_log();
@@ -364,6 +362,9 @@ void gerarel()
       if(smartfilter)
          smartfilter_report();
 
+      if(strlen(DansGuardianConf) > 0)
+         dansguardian_report();
+
       if(strlen(SquidGuardConf) > 0)
          squidguard_report();
 
