@@ -1,7 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ *
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -20,7 +23,6 @@
  *
  */
 
-
 #include "include/conf.h"
 
 void siteuser()
@@ -61,7 +63,7 @@ void siteuser()
    fgets(periodo,sizeof(periodo),fp_in);
    fclose(fp_in);
 
-   sprintf(csort,"export LC_ALL=C;sort -k 4,4 -k 1,1 -o %s %s",geral2,geral);
+   sprintf(csort,"sort -k 4,4 -k 1,1 -o %s %s",geral2,geral);
    system(csort);
 
    if((fp_in=fopen(geral2,"r"))==NULL) {
@@ -131,6 +133,24 @@ void siteuser()
          continue;
       if(userip)
          fixip(user);
+
+	if(UserTabFile[0] != '\0') {
+	    sprintf(warea,":%s:",user);
+	    if((str=(char *) strstr(userfile,warea)) != (char *) NULL ) {
+    		z1=0;
+    		str2=(char *) strstr(str+1,":");
+    		str2++;
+		bzero(name, MAXLEN);
+                while(str2[z1] != ':') {
+            	    name[z1]=str2[z1];
+	            z1++;
+		}
+	    } else strcpy(name,user);
+	} else strcpy(name,user);
+
+      if(strcmp(Ip2Name,"yes") == 0)
+         ip2name(user);
+
       if(strcmp(Ip2Name,"yes") == 0)
          ip2name(user);
 
@@ -143,9 +163,9 @@ void siteuser()
          regs++;
       }
       
-      sprintf(wuser," %s ",user);
+      sprintf(wuser," %s ",name);
       if(strstr(users,wuser) == 0 && strcmp(url,ourl) == 0) {
-         strcat(users,user);
+         strcat(users,name);
          strcat(users," ");
          ucount++;
          if(ucount>4) {
@@ -168,7 +188,7 @@ void siteuser()
          fputs(html,fp_ou);
          regs++;
          ucount=0;
-	 strcpy(users,user);
+	 strcpy(users,name);
          strcat(users," ");
          strcpy(ourl,url);
       }
