@@ -1,7 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ *
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -35,7 +38,7 @@ int topuser()
    int posicao=0;
    char olduser[MAXLEN], csort[MAXLEN], periodo[MAXLEN], arqper[MAXLEN];
    char wger[MAXLEN], top1[MAXLEN], top2[MAXLEN], top3[MAXLEN];
-   char user[MAXLEN], nacc[20], nbytes[20], url[1024], preg[8000], tusr[MAXLEN];
+   char user[MAXLEN], nacc[20], nbytes[20], preg[MAXLEN], tusr[MAXLEN];
    char ip[MAXLEN], hora[9], data[11], elap[15], incac[15], oucac[15], html[MAXLEN];
    char ipantes[MAXLEN], nameantes[MAXLEN];
    char sfield[10]="2,2";
@@ -169,7 +172,7 @@ int topuser()
    if(strcmp(TopuserSortOrder,"normal") == 0)
       order[0]='\0';
 
-   sprintf(csort,"export LC_ALL=C;sort -n -T %s %s -k %s -o %s %s", TempDir, order, sfield, top1, top2);
+   sprintf(csort,"sort -n -T %s %s -k %s -o %s %s", TempDir, order, sfield, top1, top2);
    system(csort);
 
    unlink(top2);
@@ -257,6 +260,11 @@ int topuser()
       fputs(preg,fp_top3);
    }
 
+   if(dansguardian_count) {
+     sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"dansguardian.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[128],text[55]);
+     fputs(preg,fp_top3);
+   }
+
    if(squidguard_count) {
      sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"squidguard.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[122],text[55]);
      fputs(preg,fp_top3);
@@ -427,9 +435,8 @@ int topuser()
 	 unlink(val1);
       }
 
-      if(UserTabFile[0] != '\0') {
+      if(UserTabFile[0] != '\0' && strstr(user2,".") != 0) {
          sprintf(warea,":%s:",user2);
-	 
          if((str=(char *) strstr(userfile,warea)) != (char *) NULL ) {
             z1=0;
             str2=(char *) strstr(str+1,":");
@@ -451,9 +458,9 @@ int topuser()
 
       twork=my_atoll(nacc);
       my_lltoa(twork,nacc,0);
-      sprintf(wwork1,"%s",fixnum(twork));
-      sprintf(wwork2,"%s",fixnum(tnbytes));
-      sprintf(wwork3,"%s",fixnum(tnelap));
+      sprintf(wwork1,"%s",fixnum(twork,1));
+      sprintf(wwork2,"%s",fixnum(tnbytes,1));
+      sprintf(wwork3,"%s",fixnum(tnelap,1));
 
       sprintf(val1,"%d",posicao);
 #ifdef HAVE_GD
@@ -537,9 +544,9 @@ int topuser()
             ouperc=atol(oucac) / ouperc;
          } else ouperc = 0;
 
-	 sprintf(wwork1,"%s",fixnum(ttnacc));
-	 sprintf(wwork2,"%s",fixnum(ttnbytes));
-	 sprintf(wwork3,"%s",fixnum(ttnelap));
+	 sprintf(wwork1,"%s",fixnum(ttnacc,1));
+	 sprintf(wwork2,"%s",fixnum(ttnbytes,1));
+	 sprintf(wwork3,"%s",fixnum(ttnelap,1));
 
          strcpy(hbc1,"class=\"header2\"");
          strcpy(hbc2,"class=\"header2\"");
@@ -605,9 +612,9 @@ int topuser()
 
    twork=ttnacc/totuser;
    twork2=ttnelap/totuser;
-   sprintf(wwork1,"%s",fixnum(twork));
-   sprintf(wwork2,"%s",fixnum(tnbytes));
-   sprintf(wwork3,"%s",fixnum(twork2));
+   sprintf(wwork1,"%s",fixnum(twork,1));
+   sprintf(wwork2,"%s",fixnum(tnbytes,1));
+   sprintf(wwork3,"%s",fixnum(twork2,1));
 
    if(strstr(TopUserFields,"CONNECT") == 0) {
       bzero(wwork1, 255);
