@@ -2,6 +2,9 @@
  * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
  *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ *
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -39,7 +42,7 @@ void usage(char *prog)
   fprintf(stderr, "%5s-o %s\n"," ",text[38]);
   fprintf(stderr, "%5s-p %s (%s)\n"," ",text[29],text[44]);
   fprintf(stderr, "%5s-s %s [Eg. www.microsoft.com, www.netscape.com]\n"," ",text[30]);
-  fprintf(stderr, "%5s-t %s [HH, HH:MM, HH:MM:SS]\n"," ",text[31]);
+  fprintf(stderr, "%5s-t %s [HH, HH:MM]\n"," ",text[31]);
   fprintf(stderr, "%5s-u %s\n"," ",text[32]);
   fprintf(stderr, "%5s-w %s\n"," ",text[34]);
   fprintf(stderr, "%5s-x %s\n"," ",text[36]);
