@@ -1,7 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ *
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -115,7 +118,7 @@ void useragent()
       debuga(msg);
    }
 
-   sprintf(csort,"export LC_ALL=C;sort -n -t '\\' -k 4,4 -k 3,3 -k 2,2 -k 1,1 -o %s %s",tmp2,tmp);
+   sprintf(csort,"sort -n -t '\\' -k 4,4 -k 3,3 -k 2,2 -k 1,1 -o %s %s",tmp2,tmp);
    system(csort);
 
    unlink(tmp);
@@ -210,7 +213,7 @@ void useragent()
    fclose(fp_in);
    fclose(fp_ou);
 
-   sprintf(csort,"export LC_ALL=C;sort -n -t '\\' -k 3,3 -o %s %s",tmp,tmp2);
+   sprintf(csort,"sort -n -t '\\' -k 3,3 -o %s %s",tmp,tmp2);
    system(csort);
 
    unlink(tmp2);
@@ -258,7 +261,7 @@ void useragent()
 
    unlink(tmp);
 
-   sprintf(csort,"export LC_ALL=C;sort -n -r -k 1,1 -o %s %s",tmp,tmp2);
+   sprintf(csort,"sort -n -r -k 1,1 -o %s %s",tmp,tmp2);
    system(csort);
 
    unlink(tmp2);
