@@ -1,7 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ *
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -236,31 +239,31 @@ void my_lltoa(unsigned long long int n, char s[], int len)
 
 void builddia(char *dia, char *mes, char *ano, char *df, char *wdata)
 {
-   char ndia[9];
+   char ndia[11];
    char nmes[3];
    int  x;
 
+   if(strlen(dia) < 1) return;
+
    ndia[0]='\0';
    nmes[0]='\0';
 
-   for(x=0; x<=12; x++) {
+   for(x=0; x<12; x++) {
       if(strcmp(mtab1[x],mes) == 0) {
          strncpy(nmes,mtab2[x],sizeof(nmes)-1);
          nmes[sizeof(nmes)-1]=0;
+         break;
       }
    }
 
-   snprintf(wdata,6,"%s%s%s",ano,nmes,dia);
+   snprintf(wdata,9,"%s%s%s",ano,nmes,dia);
 
    if(strncmp(df,"u",1) != 0)
       snprintf(ndia,sizeof(ndia),"%s/%s/%s",dia,nmes,ano);
     else
       snprintf(ndia,sizeof(ndia),"%s/%s/%s",nmes,dia,ano);
 
-   strncpy(dia,ndia,sizeof(dia)-1);
-   dia[sizeof(dia)-1]=0;
-
-   return;
+   strcpy(dia,ndia);
 
 }
 
@@ -272,15 +275,13 @@ void buildymd(char *dia, char *mes, char *ano, char *wdata)
 
    nmes[0]='\0';
 
-   for(x=0; x<=12; x++) {
+   for(x=0; x<12; x++) {
       if(strcmp(mtab1[x],mes) == 0)
          strcpy(nmes,mtab2[x]);
    }
 
    sprintf(wdata,"%s%s%s",ano,nmes,dia);
 
-   return;
-
 }
 
 
@@ -288,13 +289,11 @@ void conv_month(char *month)
 {
    int  x;
 
-   for(x=0; x<=12; x++) {
+   for(x=0; x<12; x++) {
       if(strcmp(mtab1[x],month) == 0)
          strcpy(month,mtab2[x]);
    }
 
-   return;
-
 }
 
 
@@ -302,7 +301,7 @@ void conv_month_name(char *month)
 {
    int x;
 
-   for(x=0; x<=12; x++) {
+   for(x=0; x<12; x++) {
       if(strcmp(mtab2[x],month) == 0)
          strcpy(month,mtab1[x]);
    }
@@ -325,7 +324,7 @@ void fixper(char *tbuf, char *periodo, char *duntil)
    strncpy(ano,duntil,4);
    ano[4]='\0';
 
-   for(x=0; x<=12; x++) {
+   for(x=0; x<12; x++) {
       if(strcmp(mtab2[x],mes) == 0)
          strcpy(mes,mtab1[x]);
    }
@@ -336,7 +335,6 @@ void fixper(char *tbuf, char *periodo, char *duntil)
       sprintf(warea,"%s%s%s",ano,mes,dia);
 
    strcat(periodo,warea);
-   return;
 }
 
 
@@ -344,7 +342,6 @@ void debuga(char *msg)
 {
   fprintf(stderr, "SARG: %s\n",msg);
 
-  return;
 }
 
 
@@ -352,7 +349,6 @@ void debugaz(char *head, char *msg)
 {
   fprintf(stderr, "SARG: (util) %s=%s\n",head, msg);
 
-  return;
 }
 
 
@@ -382,11 +378,10 @@ void fixip(char *ip)
    ip[0]='\0';
    sprintf(ip,"%s%s%s%s%s%s%s",n1,sep,n2,sep,n3,sep,wip);
 
-   return;
 }
 
 
-char *fixnum(long long int inteiro)
+char *fixnum(long long int value, int n)
 #define MAXIMO 1024
 {
    char num[MAXIMO];
@@ -398,32 +393,52 @@ char *fixnum(long long int inteiro)
    register int i, j, k;
    static char abbrev[30];
       
-   my_lltoa(inteiro, num, 0);
+   my_lltoa(value, num, 0);
 
    if(strcmp(DisplayedValues,"abbreviation") == 0) {
-      if(inteiro < 1000) {
-         perc=inteiro;
-         sprintf(abbrev,"%3.0f",perc);
+      if(strlen(num) <= 3)
+         sprintf(abbrev,"%s",num);
+      if(strlen(num) == 4 || strlen(num) == 7 || strlen(num) == 10 || strlen(num) == 13) {
+         snprintf(abbrev,2,"%s",num);
+         strncat(abbrev,".",1);
+         strncat(abbrev,num+1,2);
+         if(!n) return(abbrev);
+         if(strlen(num) == 4)
+            strncat(abbrev,"K",1);
+         else if(strlen(num) == 7)
+            strncat(abbrev,"M",1);
+         else if(strlen(num) == 10)
+            strncat(abbrev,"G",1);
+         else if(strlen(num) == 13)
+            strncat(abbrev,"T",1);
       }
-      if(inteiro > 999 && inteiro <= 999999) {
-         perc=inteiro / 1000;
-         if((inteiro % 1000) >= 500) perc++;
-         sprintf(abbrev,"%3.0fK",perc);
+      if(strlen(num) == 5 || strlen(num) == 8 || strlen(num) == 11 || strlen(num) == 14) {
+         snprintf(abbrev,3,"%s",num);
+         strncat(abbrev,".",1);
+         strncat(abbrev,num+2,2);
+         if(!n) return(abbrev);
+         if(strlen(num) == 5)
+            strncat(abbrev,"K",1);
+         else if(strlen(num) == 8)
+            strncat(abbrev,"M",1);
+         else if(strlen(num) == 11)
+            strncat(abbrev,"G",1);
+         else if(strlen(num) == 14)
+            strncat(abbrev,"T",1);
       }
-      if(inteiro >999999 && inteiro <= 999999999) {
-         perc=inteiro / 1000000;
-         if((inteiro % 1000000) >= 500) perc++;
-         sprintf(abbrev,"%3.0fM",perc);
-      }
-      if(inteiro > 999999999 && inteiro <= 999999999999) {
-         perc=inteiro / 1000000000;
-         if((inteiro % 1000000000) >= 500) perc++;
-         sprintf(abbrev,"%3.0fG",perc);
-      }
-      if(inteiro > 999999999999) {
-         perc=inteiro / 1000000000000;
-         if((inteiro % 1000000000000) >= 500) perc++;
-         sprintf(abbrev,"%3.0fT",perc);
+      if(strlen(num) == 6 || strlen(num) == 9 || strlen(num) == 12 || strlen(num) == 15) {
+         snprintf(abbrev,4,"%s",num);
+         strncat(abbrev,".",1);
+         strncat(abbrev,num+3,2);
+         if(!n) return(abbrev);
+         if(strlen(num) == 6)
+            strncat(abbrev,"K",1);
+         else if(strlen(num) == 9)
+            strncat(abbrev,"M",1);
+         else if(strlen(num) == 12)
+            strncat(abbrev,"G",1);
+         else if(strlen(num) == 15)
+            strncat(abbrev,"T",1);
       }
 
       return(abbrev);
@@ -567,7 +582,7 @@ void obttotal(char *dirname, char *name, char *tbytes, char *tuser, char *media)
       getword(warea,buf,' ');
       getword(warea,buf,' ');
       twork=my_atoll(warea);
-      sprintf(tbytes,"%s",fixnum(twork));
+      sprintf(tbytes,"%s",fixnum(twork,1));
    }
    fclose(fp_in);
 
@@ -579,7 +594,7 @@ void obttotal(char *dirname, char *name, char *tbytes, char *tuser, char *media)
    
    wtuser=my_atoll(tuser);
    med=my_atoll(warea) / wtuser;
-   sprintf(media,"%s",fixnum(med));
+   sprintf(media,"%s",fixnum(med,1));
 
    return;
 
@@ -763,7 +778,7 @@ char *fixtime(long int elap)
    static char buf[12];
 
    if(strcmp(datetimeby,"bytes") == 0) {
-      sprintf(buf,"%s",fixnum(elap));
+      sprintf(buf,"%s",fixnum(elap,1));
       return buf;
    }
 
